@@ -19,8 +19,8 @@
  /*
   * External interface.
   */
-extern int trace_append(int, const char *, time_t, RECIPIENT *,
-			        const char *, DSN *);
+extern int trace_append(int, const char *, MSG_STATS *, RECIPIENT *,
+			        const char *, const POL_STATS *, DSN *);
 extern int trace_flush(int, const char *, const char *, const char *,
 		               const char *, const char *, int);
 
@@ -33,6 +33,9 @@ extern int trace_flush(int, const char *, const char *, const char *,
 /*	IBM T.J. Watson Research
 /*	P.O. Box 704
 /*	Yorktown Heights, NY 10598, USA
+/*
+/*	Wietse Venema
+/*	porcupine.org
 /*--*/
 
 #endif
